==> kdegames-4.2.4-i486-1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkggznet.so.4 )
( cd usr/lib ; ln -sf libkggznet.so.4.2.0 libkggznet.so.4 )
( cd usr/lib ; rm -rf libkggznet.so )
( cd usr/lib ; ln -sf libkggznet.so.4 libkggznet.so )
( cd usr/lib ; rm -rf libkolfprivate.so )
( cd usr/lib ; ln -sf libkolfprivate.so.4 libkolfprivate.so )
( cd usr/lib ; rm -rf libkdegames.so.5 )
( cd usr/lib ; ln -sf libkdegames.so.5.0.0 libkdegames.so.5 )
( cd usr/lib ; rm -rf libkolfprivate.so.4 )
( cd usr/lib ; ln -sf libkolfprivate.so.4.2.0 libkolfprivate.so.4 )
( cd usr/lib ; rm -rf libkmahjongglib.so.4 )
( cd usr/lib ; ln -sf libkmahjongglib.so.4.2.0 libkmahjongglib.so.4 )
( cd usr/lib ; rm -rf libiris_ksirk.so.2 )
( cd usr/lib ; ln -sf libiris_ksirk.so.2.0.0 libiris_ksirk.so.2 )
( cd usr/lib ; rm -rf libkggzgames.so.4 )
( cd usr/lib ; ln -sf libkggzgames.so.4.2.0 libkggzgames.so.4 )
( cd usr/lib ; rm -rf libiris_ksirk.so )
( cd usr/lib ; ln -sf libiris_ksirk.so.2 libiris_ksirk.so )
( cd usr/lib ; rm -rf libkdegames.so )
( cd usr/lib ; ln -sf libkdegames.so.5 libkdegames.so )
( cd usr/lib ; rm -rf libkggzmod.so )
( cd usr/lib ; ln -sf libkggzmod.so.4 libkggzmod.so )
( cd usr/lib ; rm -rf libkmahjongglib.so )
( cd usr/lib ; ln -sf libkmahjongglib.so.4 libkmahjongglib.so )
( cd usr/lib ; rm -rf libkggzmod.so.4 )
( cd usr/lib ; ln -sf libkggzmod.so.4.2.0 libkggzmod.so.4 )
( cd usr/lib ; rm -rf libkggzgames.so )
( cd usr/lib ; ln -sf libkggzgames.so.4 libkggzgames.so )
( cd usr/share/doc/HTML/en/lskat ; rm -rf common )
( cd usr/share/doc/HTML/en/lskat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd usr/share/doc/HTML/en/kjumpingcube ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfourinline ; rm -rf common )
( cd usr/share/doc/HTML/en/kfourinline ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konquest ; rm -rf common )
( cd usr/share/doc/HTML/en/konquest ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksudoku ; rm -rf common )
( cd usr/share/doc/HTML/en/ksudoku ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/katomic ; rm -rf common )
( cd usr/share/doc/HTML/en/katomic ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/knetwalk ; rm -rf common )
( cd usr/share/doc/HTML/en/knetwalk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kblocks ; rm -rf common )
( cd usr/share/doc/HTML/en/kblocks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/bomber ; rm -rf common )
( cd usr/share/doc/HTML/en/bomber ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kubrick ; rm -rf common )
( cd usr/share/doc/HTML/en/kubrick ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/killbots ; rm -rf common )
( cd usr/share/doc/HTML/en/killbots ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kshisen ; rm -rf common )
( cd usr/share/doc/HTML/en/kshisen ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd usr/share/doc/HTML/en/kbattleship ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/en/ktuberling ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd usr/share/doc/HTML/en/kblackbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbreakout ; rm -rf common )
( cd usr/share/doc/HTML/en/kbreakout ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kollision ; rm -rf common )
( cd usr/share/doc/HTML/en/kollision ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbounce ; rm -rf common )
( cd usr/share/doc/HTML/en/kbounce ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kiriki ; rm -rf common )
( cd usr/share/doc/HTML/en/kiriki ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/bovo ; rm -rf common )
( cd usr/share/doc/HTML/en/bovo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdiamond ; rm -rf common )
( cd usr/share/doc/HTML/en/kdiamond ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksame ; rm -rf common )
( cd usr/share/doc/HTML/en/ksame ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmines ; rm -rf common )
( cd usr/share/doc/HTML/en/kmines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kreversi ; rm -rf common )
( cd usr/share/doc/HTML/en/kreversi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/en/kmahjongg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd usr/share/doc/HTML/en/kgoldrunner ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksirk ; rm -rf common )
( cd usr/share/doc/HTML/en/ksirk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kolf ; rm -rf common )
( cd usr/share/doc/HTML/en/kolf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/klines ; rm -rf common )
( cd usr/share/doc/HTML/en/klines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksquares ; rm -rf common )
( cd usr/share/doc/HTML/en/ksquares ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kapman ; rm -rf common )
( cd usr/share/doc/HTML/en/kapman ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kpat ; rm -rf common )
( cd usr/share/doc/HTML/en/kpat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd usr/share/doc/HTML/en/kspaceduel ; ln -sf /usr/share/doc/HTML/en/common common )

==> kdegames-4.4.3-i486-1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkggznet.so )
( cd usr/lib ; ln -sf libkggznet.so.4 libkggznet.so )
( cd usr/lib ; rm -rf libkolfprivate.so.4 )
( cd usr/lib ; ln -sf libkolfprivate.so.4.4.0 libkolfprivate.so.4 )
( cd usr/lib ; rm -rf libkggzmod.so.4 )
( cd usr/lib ; ln -sf libkggzmod.so.4.4.0 libkggzmod.so.4 )
( cd usr/lib ; rm -rf libpala.so.0 )
( cd usr/lib ; ln -sf libpala.so.0.1.0 libpala.so.0 )
( cd usr/lib ; rm -rf libiris_ksirk.so.2 )
( cd usr/lib ; ln -sf libiris_ksirk.so.2.0.0 libiris_ksirk.so.2 )
( cd usr/lib ; rm -rf libkolfprivate.so )
( cd usr/lib ; ln -sf libkolfprivate.so.4 libkolfprivate.so )
( cd usr/lib ; rm -rf libkmahjongglib.so.4 )
( cd usr/lib ; ln -sf libkmahjongglib.so.4.4.0 libkmahjongglib.so.4 )
( cd usr/lib ; rm -rf libiris_ksirk.so )
( cd usr/lib ; ln -sf libiris_ksirk.so.2 libiris_ksirk.so )
( cd usr/lib ; rm -rf libkggzgames.so.4 )
( cd usr/lib ; ln -sf libkggzgames.so.4.4.0 libkggzgames.so.4 )
( cd usr/lib ; rm -rf libkmahjongglib.so )
( cd usr/lib ; ln -sf libkmahjongglib.so.4 libkmahjongglib.so )
( cd usr/lib ; rm -rf libpala.so )
( cd usr/lib ; ln -sf libpala.so.0 libpala.so )
( cd usr/lib ; rm -rf libkdegames.so.5 )
( cd usr/lib ; ln -sf libkdegames.so.5.0.0 libkdegames.so.5 )
( cd usr/lib ; rm -rf libkggzmod.so )
( cd usr/lib ; ln -sf libkggzmod.so.4 libkggzmod.so )
( cd usr/lib ; rm -rf libkdegames.so )
( cd usr/lib ; ln -sf libkdegames.so.5 libkdegames.so )
( cd usr/lib ; rm -rf libkggzgames.so )
( cd usr/lib ; ln -sf libkggzgames.so.4 libkggzgames.so )
( cd usr/lib ; rm -rf libkggznet.so.4 )
( cd usr/lib ; ln -sf libkggznet.so.4.4.0 libkggznet.so.4 )
( cd usr/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd usr/share/doc/HTML/en/kblackbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/killbots ; rm -rf common )
( cd usr/share/doc/HTML/en/killbots ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/klines ; rm -rf common )
( cd usr/share/doc/HTML/en/klines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/granatier ; rm -rf common )
( cd usr/share/doc/HTML/en/granatier ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksame ; rm -rf common )
( cd usr/share/doc/HTML/en/ksame ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd usr/share/doc/HTML/en/kspaceduel ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kblocks ; rm -rf common )
( cd usr/share/doc/HTML/en/kblocks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbreakout ; rm -rf common )
( cd usr/share/doc/HTML/en/kbreakout ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konquest ; rm -rf common )
( cd usr/share/doc/HTML/en/konquest ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd usr/share/doc/HTML/en/kgoldrunner ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmines ; rm -rf common )
( cd usr/share/doc/HTML/en/kmines ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kiriki ; rm -rf common )
( cd usr/share/doc/HTML/en/kiriki ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kapman ; rm -rf common )
( cd usr/share/doc/HTML/en/kapman ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kollision ; rm -rf common )
( cd usr/share/doc/HTML/en/kollision ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/en/kmahjongg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/en/ktuberling ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksquares ; rm -rf common )
( cd usr/share/doc/HTML/en/ksquares ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd usr/share/doc/HTML/en/kjumpingcube ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kreversi ; rm -rf common )
( cd usr/share/doc/HTML/en/kreversi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kshisen ; rm -rf common )
( cd usr/share/doc/HTML/en/kshisen ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksirkskineditor ; rm -rf common )
( cd usr/share/doc/HTML/en/ksirkskineditor ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksudoku ; rm -rf common )
( cd usr/share/doc/HTML/en/ksudoku ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kpat ; rm -rf common )
( cd usr/share/doc/HTML/en/kpat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/lskat ; rm -rf common )
( cd usr/share/doc/HTML/en/lskat ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/bovo ; rm -rf common )
( cd usr/share/doc/HTML/en/bovo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksirk ; rm -rf common )
( cd usr/share/doc/HTML/en/ksirk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd usr/share/doc/HTML/en/kbattleship ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbounce ; rm -rf common )
( cd usr/share/doc/HTML/en/kbounce ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/bomber ; rm -rf common )
( cd usr/share/doc/HTML/en/bomber ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktron ; rm -rf common )
( cd usr/share/doc/HTML/en/ktron ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfourinline ; rm -rf common )
( cd usr/share/doc/HTML/en/kfourinline ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdiamond ; rm -rf common )
( cd usr/share/doc/HTML/en/kdiamond ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kigo ; rm -rf common )
( cd usr/share/doc/HTML/en/kigo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/knetwalk ; rm -rf common )
( cd usr/share/doc/HTML/en/knetwalk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kolf ; rm -rf common )
( cd usr/share/doc/HTML/en/kolf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kubrick ; rm -rf common )
( cd usr/share/doc/HTML/en/kubrick ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/katomic ; rm -rf common )
( cd usr/share/doc/HTML/en/katomic ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/palapeli ; rm -rf common )
( cd usr/share/doc/HTML/en/palapeli ; ln -sf /usr/share/doc/HTML/en/common common )
